@@ -21,26 +21,18 @@
 
 import codecs
 import os
-import time
-from pathlib import Path
 from typing import Dict, List, Optional, Union
 
 import cloudpickle as pickle
 import requests
 from requests.adapters import HTTPAdapter
-from sqlalchemy.orm import Session
 from urllib3.util import Retry
 
-from covalent._workflow.transport import TransportableObject
-
-from .. import _workflow as ct
-from .._data_store.datastore import DataStore
-from .._data_store.models import Lattice
 from .._shared_files import logger
 from .._shared_files.config import get_config
+from .._shared_files.exceptions import MissingLatticeRecordError
 from .result import Result
 from .wait import EXTREME
-from .write_result_to_db import MissingLatticeRecordError, load_file
 
 app_log = logger.app_log
 log_stack_info = logger.log_stack_info
@@ -76,76 +68,6 @@ def get_result(dispatch_id: str, wait: bool = False) -> Result:
     return result_object
 
 
-def result_from(lattice_record: Lattice) -> Result:
-    """Re-hydrate result object from the lattice record."""
-
-    function = load_file(
-        storage_path=lattice_record.storage_path, filename=lattice_record.function_filename
-    )
-    executor_data = load_file(
-        storage_path=lattice_record.storage_path, filename=lattice_record.executor_data_filename
-    )
-    workflow_executor_data = load_file(
-        storage_path=lattice_record.storage_path,
-        filename=lattice_record.workflow_executor_data_filename,
-    )
-    inputs = load_file(
-        storage_path=lattice_record.storage_path, filename=lattice_record.inputs_filename
-    )
-    named_args = load_file(
-        storage_path=lattice_record.storage_path, filename=lattice_record.named_args_filename
-    )
-    named_kwargs = load_file(
-        storage_path=lattice_record.storage_path, filename=lattice_record.named_kwargs_filename
-    )
-    error = load_file(
-        storage_path=lattice_record.storage_path, filename=lattice_record.error_filename
-    )
-    transport_graph = load_file(
-        storage_path=lattice_record.storage_path, filename=lattice_record.transport_graph_filename
-    )
-    output = load_file(
-        storage_path=lattice_record.storage_path, filename=lattice_record.results_filename
-    )
-
-    executor = lattice_record.executor
-    workflow_executor = lattice_record.workflow_executor
-
-    attributes = {
-        "metadata": {
-            "executor": executor,
-            "executor_data": executor_data,
-            "workflow_executor": workflow_executor,
-            "workflow_executor_data": workflow_executor_data,
-        },
-        "args": inputs["args"],
-        "kwargs": inputs["kwargs"],
-        "named_args": named_args,
-        "named_kwargs": named_kwargs,
-        "transport_graph": transport_graph,
-        "workflow_function": function,
-    }
-
-    def dummy_function(x):
-        return x
-
-    lat = ct.lattice(dummy_function)
-    lat.__dict__ = attributes
-
-    result = Result(
-        lat,
-        str(Path(lattice_record.storage_path).parent),
-        dispatch_id=lattice_record.dispatch_id,
-    )
-    result._status = lattice_record.status
-    result._error = error
-    result._inputs = inputs
-    result._start_time = lattice_record.started_at
-    result._end_time = lattice_record.completed_at
-    result._result = output if output is not None else TransportableObject(None)
-    return result
-
-
 def _get_result_from_dispatcher(
     dispatch_id: str,
     wait: bool = False,
@@ -241,7 +163,6 @@ def redispatch_result(result_object: Result, dispatcher: str = None) -> str:
 
 
 def sync(
-    db: DataStore,
     dispatch_id: Optional[Union[List[str], str]] = None,
 ) -> None:
     """
@@ -260,10 +181,9 @@ def sync(
         for d in dispatch_id:
             _get_result_from_dispatcher(d, wait=True, status_only=True)
     else:
-        with Session(db.engine) as session:
-            rows = session.query(Lattice).all()
-        for row in rows:
-            _get_result_from_dispatcher(row.dispatch_id, wait=True, status_only=True)
+        raise Exception(
+            f"dispatch_id must be a string or a list. You passed a {type(dispatch_id)}."
+        )
 
 
 def cancel(
