@@ -29,12 +29,14 @@ from sqlalchemy.orm import Session
 from covalent_ui.api.v1.data_layer.summary_dal import Summary
 from covalent_ui.api.v1.database.config.db import engine
 from covalent_ui.api.v1.models.dispatch_model import (
+    DeleteAllDispatchesRequest,
     DeleteDispatchesRequest,
     DeleteDispatchesResponse,
     DispatchDashBoardResponse,
     SortBy,
     SortDirection,
 )
+from covalent_ui.api.v1.utils.status import Status
 
 routes: APIRouter = APIRouter()
 
@@ -42,10 +44,11 @@ routes: APIRouter = APIRouter()
 @routes.get("/list")
 def get_all_dispatches(
     count: Optional[conint(gt=0, lt=100)] = Query(10),
-    offset: Optional[int] = Query(0),
+    offset: Optional[conint(ge=0, lt=100)] = Query(0),
     sort_by: Optional[SortBy] = SortBy.RUNTIME,
     search: Optional[str] = "",
     sort_direction: Optional[SortDirection] = SortDirection.DESCENDING,
+    status_filter: Optional[Status] = Status.ALL,
 ):
     """Get All Dispatches
 
@@ -57,7 +60,7 @@ def get_all_dispatches(
     """
     with Session(engine) as session:
         summary = Summary(session)
-        return summary.get_summary(count, offset, sort_by, search, sort_direction)
+        return summary.get_summary(count, offset, sort_by, search, sort_direction, status_filter)
 
 
 @routes.get("/overview", response_model=DispatchDashBoardResponse)
@@ -76,7 +79,7 @@ def get_dashboard_details():
 
 
 @routes.post("/delete", response_model=DeleteDispatchesResponse)
-def delete_dispatches(req: DeleteDispatchesRequest):
+def delete_dispatches(req: Optional[DeleteDispatchesRequest]):
     """Delete one or more Dispatches
 
     Args:
@@ -90,3 +93,20 @@ def delete_dispatches(req: DeleteDispatchesRequest):
     with Session(engine) as session:
         summary = Summary(session)
         return summary.delete_dispatches(req)
+
+
+@routes.post("/delete-all", response_model=DeleteDispatchesResponse)
+def delete_all_dispatches(req: Optional[DeleteAllDispatchesRequest]):
+    """Delete one or more Dispatches
+
+    Args:
+        req: Dispatch Dispatch Request
+
+    Returns:
+        List of deleted dispatches if success
+        List of deleted dispatches if fails
+    """
+
+    with Session(engine) as session:
+        summary = Summary(session)
+        return summary.delete_all_dispatches(req)
